.. _costs:

Costs
=====

.. currentmodule:: skchange.costs

.. autosummary::
    :toctree: auto_generated/
    :template: functions.rst

    BaseCost
    L2Cost
    GaussianCost
    GaussianCovCost

Utility functions
-----------------

.. currentmodule:: skchange.costs.utils

.. autosummary::
    :toctree: auto_generated/
    :template: functions.rst

    check_mean
    check_var
    check_cov
